@@ -26,6 +26,8 @@ use crate::OP_ACK;
 
 use crate::borrow::Cow;
 use crate::client::AsyncClient;
+#[cfg(feature = "broker-api")]
+use crate::common::{ClientInfo, ClientList};
 use crate::{EventChannel, OpConfirm};
 use crate::{Frame, FrameData, FrameKind, FrameOp, QoS};
 
@@ -33,6 +35,8 @@ use crate::{Frame, FrameData, FrameKind, FrameOp, QoS};
 use crate::rpc::{Rpc, RpcClient};
 #[cfg(feature = "broker-api")]
 use crate::rpc::{RpcError, RpcEvent, RpcHandlers, RpcResult};
+#[cfg(feature = "broker-api")]
+use serde_value::Value;
 
 use async_trait::async_trait;
 
@@ -132,6 +136,7 @@ macro_rules! publish {
 }
 
 pub struct Client {
+    name: String,
     client: Arc<ElbusClient>,
     db: Arc<BrokerDb>,
     rx: Option<EventChannel>,
@@ -263,6 +268,10 @@ impl AsyncClient for Client {
     fn get_connected_beacon(&self) -> Option<Arc<atomic::AtomicBool>> {
         None
     }
+    #[inline]
+    fn get_name(&self) -> &str {
+        self.name.as_str()
+    }
 }
 
 impl Client {
@@ -286,6 +295,7 @@ enum ElbusClientType {
 }
 
 impl ElbusClientType {
+    #[allow(dead_code)]
     fn as_str(&self) -> &str {
         match self {
             ElbusClientType::Internal => "internal",
@@ -295,22 +305,7 @@ impl ElbusClientType {
     }
 }
 
-impl fmt::Display for ElbusClientType {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self.as_str())
-    }
-}
-
-#[cfg(feature = "broker-api")]
-impl serde::Serialize for ElbusClientType {
-    fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
-    where
-        S: serde::Serializer,
-    {
-        serializer.serialize_str(self.as_str())
-    }
-}
-
+#[allow(dead_code)]
 #[derive(Debug)]
 struct ElbusClient {
     name: String,
@@ -417,7 +412,6 @@ impl BrokerDb {
         self.clients.write().unwrap().remove(&client.name);
     }
 }
-
 pub struct Broker {
     db: Arc<BrokerDb>,
     services: Vec<JoinHandle<()>>,
@@ -435,28 +429,20 @@ struct BrokerRpcHandlers {
 #[async_trait]
 impl RpcHandlers for BrokerRpcHandlers {
     async fn handle_call(&self, event: RpcEvent) -> RpcResult {
+        let method = event.parse_method()?;
+        if method == "benchmark.test" {
+            return Ok(Some(event.payload().to_vec()));
+        }
+        let payload = event.payload();
+        let params: HashMap<String, Value> = if payload.is_empty() {
+            HashMap::new()
+        } else {
+            rmp_serde::from_read_ref(event.payload())?
+        };
         match event.parse_method()? {
-            "list_clients" => {
-                #[derive(serde::Serialize, Eq, PartialEq)]
-                struct ClientInfo<'a> {
-                    name: &'a str,
-                    tp: ElbusClientType,
-                    source: Option<&'a str>,
-                    port: Option<&'a str>,
-                }
-                impl<'a> Ord for ClientInfo<'a> {
-                    fn cmp(&self, other: &Self) -> std::cmp::Ordering {
-                        self.name.cmp(other.name)
-                    }
-                }
-                impl<'a> PartialOrd for ClientInfo<'a> {
-                    fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
-                        Some(self.cmp(other))
-                    }
-                }
-                #[derive(serde::Serialize)]
-                struct Clients<'a> {
-                    clients: Vec<ClientInfo<'a>>,
+            "client.list" => {
+                if !params.is_empty() {
+                    return Err(RpcError::params());
                 }
                 let db = self.db.clients.read().unwrap();
                 let mut clients: Vec<ClientInfo> = db
@@ -464,13 +450,13 @@ impl RpcHandlers for BrokerRpcHandlers {
                     .into_iter()
                     .map(|v| ClientInfo {
                         name: &v.name,
-                        tp: v.tp,
+                        tp: v.tp.as_str(),
                         source: v.source.as_deref(),
                         port: v.port.as_deref(),
                     })
                     .collect();
                 clients.sort();
-                Ok(Some(rmp_serde::to_vec_named(&Clients { clients })?))
+                Ok(Some(rmp_serde::to_vec_named(&ClientList { clients })?))
             }
             _ => Err(RpcError::method()),
         }
@@ -611,6 +597,7 @@ impl Broker {
         let client = Arc::new(c);
         self.db.register_client(client.clone())?;
         Ok(Client {
+            name: name.to_owned(),
             client,
             db: self.db.clone(),
             rx: Some(rx),
@@ -744,31 +731,8 @@ impl Broker {
                     .await?;
                 Ok(())
             } else if let Some(method) = payload.strip_prefix(':') {
-                use serde_json::value::Value;
-                let mut params: HashMap<&str, Value> = HashMap::new();
-                for pair in sp {
-                    if !pair.is_empty() {
-                        let mut psp = pair.split('=');
-                        let var = psp
-                            .next()
-                            .ok_or_else(|| Error::data("var name not specified"))?;
-                        let v = psp
-                            .next()
-                            .ok_or_else(|| Error::data("var value not specified"))?;
-                        let value = if v == "false" {
-                            Value::from(false)
-                        } else if v == "true" {
-                            Value::from(true)
-                        } else if let Ok(i) = v.parse::<i64>() {
-                            Value::from(i)
-                        } else if let Ok(f) = v.parse::<f64>() {
-                            Value::from(f)
-                        } else {
-                            Value::from(v)
-                        };
-                        params.insert(var, value);
-                    }
-                }
+                let s = sp.collect::<Vec<&str>>();
+                let params = crate::common::str_to_params_map(&s)?;
                 rpc.lock()
                     .await
                     .call0(
