@@ -24,7 +24,7 @@ use crate::{Frame, FrameData, FrameKind, FrameOp};
 
 use crate::client::AsyncClient;
 
-use log::{error, warn};
+use log::{error, trace, warn};
 
 use async_trait::async_trait;
 
@@ -84,6 +84,7 @@ impl Config {
 }
 
 pub struct Client {
+    name: String,
     writer: Writer,
     reader_fut: JoinHandle<()>,
     frame_id: u32,
@@ -143,6 +144,7 @@ macro_rules! send_frame {
         buf.extend_from_slice(&((t.len() + $payload.len() + 1) as u32).to_le_bytes());
         buf.extend_from_slice(t);
         buf.push(0x00);
+        trace!("sending elbus {:?} to {} QoS={:?}", $op, $target, $qos);
         send_frame_and_confirm!($self, &buf, $payload, $qos)
     }};
     ($self: expr, $target: expr, $header: expr, $payload: expr, $op: expr, $qos: expr) => {{
@@ -154,6 +156,7 @@ macro_rules! send_frame {
         buf.extend_from_slice(t);
         buf.push(0x00);
         buf.extend_from_slice($header);
+        trace!("sending elbus {:?} to {} QoS={:?}", $op, $target, $qos);
         send_frame_and_confirm!($self, &buf, $payload, $qos)
     }};
     ($self: expr, $payload: expr, $op: expr, $qos: expr) => {{
@@ -221,6 +224,7 @@ impl Client {
             (Writer::Tcp(writer), reader_fut, rx)
         };
         Ok(Self {
+            name: config.name.to_owned(),
             writer,
             reader_fut,
             frame_id: 0,
@@ -332,6 +336,10 @@ impl AsyncClient for Client {
     fn get_timeout(&self) -> Option<Duration> {
         Some(self.timeout)
     }
+    #[inline]
+    fn get_name(&self) -> &str {
+        self.name.as_str()
+    }
 }
 
 impl Drop for Client {
