@@ -1,16 +1,9 @@
-// TODO example: client
-// TODO example: client listener
-// TODO example: sync python
-// TODO example: async python
-// TODO js client (rpc)
-// TODO CLI tool: send messages, listen, send rpc, listen rpc, benchmark
 // TODO broker internal broadcast (topic) events
 // TODO broker info events
 // TODO tests
 // TODO rpc tests
 // TODO bus rpc: stats
 // TODO release
-// TODO release python libs
 use std::fmt;
 use std::sync::Arc;
 
@@ -39,8 +32,12 @@ pub const ERR_TIMEOUT: u8 = 0x78;
 
 pub const GREETINGS: [u8; 1] = [0xEB];
 
-/// When the frame is sent, methods do not wait for the result but return OpConfirm type to let the
-/// sender get it if required.
+pub const VERSION: &str = env!("CARGO_PKG_VERSION");
+
+pub static AUTHOR: &str = "(c) 2022 Bohemia Automation / Altertech";
+
+/// When a frame is sent, methods do not wait for the result, but they return OpConfirm type to let
+/// the sender get the result if required.
 ///
 /// When the frame is sent with QoS > 0, the Option contains Receiver<Result>
 ///
@@ -126,42 +123,49 @@ impl fmt::Display for Error {
 }
 
 impl Error {
+    #[inline]
     pub fn new(kind: ErrorKind, message: Option<impl fmt::Display>) -> Self {
         Self {
             kind,
             message: message.map(|m| m.to_string()),
         }
     }
+    #[inline]
     pub fn io(e: impl fmt::Display) -> Self {
         Self {
             kind: ErrorKind::Io,
             message: Some(e.to_string()),
         }
     }
+    #[inline]
     pub fn data(e: impl fmt::Display) -> Self {
         Self {
             kind: ErrorKind::Data,
             message: Some(e.to_string()),
         }
     }
+    #[inline]
     pub fn not_supported(e: impl fmt::Display) -> Self {
         Self {
             kind: ErrorKind::NotSupported,
             message: Some(e.to_string()),
         }
     }
+    #[inline]
     pub fn not_registered() -> Self {
         Self {
             kind: ErrorKind::NotRegistered,
             message: None,
         }
     }
+    #[inline]
     pub fn timeout() -> Self {
         Self {
             kind: ErrorKind::Timeout,
             message: None,
         }
     }
+    #[inline]
     pub fn busy(e: impl fmt::Display) -> Self {
         Self {
             kind: ErrorKind::Busy,
@@ -389,6 +393,9 @@ impl FrameData {
     }
 }
 
+pub mod borrow;
+pub mod common;
+
 #[cfg(feature = "broker")]
 pub mod broker;
 #[cfg(feature = "ipc")]
@@ -396,6 +403,5 @@ pub mod ipc;
 #[cfg(any(feature = "rpc", feature = "broker-api"))]
 pub mod rpc;
 
-pub mod borrow;
 #[cfg(any(feature = "rpc", feature = "broker", feature = "ipc"))]
 pub mod client;
